@@ -6,7 +6,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 """
-client - smart client for accessing imageio server.
+Smart client for accessing imageio server.
 
 This module exposes the public names. Anything else in this package is private
 and should not be used.
@@ -17,8 +17,13 @@ and should not be used.
 # Use for default buffer size.
 from .. _internal.io import BUFFER_SIZE
 
+from .. _internal import version
+
 # The public APIs
 from . _api import upload, download
 
 # For better user experience.
 from . _ui import ProgressBar
+
+__all__ = ("BUFFER_SIZE", "ProgressBar", "upload", "download")
+__version__ = version.string
